@@ -5,7 +5,7 @@ IFS=$'\n\t'
 echo "Installing requirements"
 sudo apt-get install -yq --no-install-recommends \
     python3-pytest python3-pytest-django \
-    python3-pip firefox \
+    python3-pip firefox smbclient\
     xvfb
 pip3 install wheel
 pip3 install splinter pytest-splinter pytest-bdd pytest-xvfb
@@ -13,11 +13,14 @@ pip3 install splinter pytest-splinter pytest-bdd pytest-xvfb
 echo "Installing geckodriver"
 (
     DL_DIR=/tmp/gecko
-    GECKO_VERSION="v0.24.0"
+    GECKO_VERSION=$(curl --silent "https://api.github.com/repos/mozilla/geckodriver/releases/latest" | grep -Po '"tag_name": "\K.*?(?=")')
     FILENAME="geckodriver-${GECKO_VERSION}-linux64.tar.gz"
     GECKO_URL="https://github.com/mozilla/geckodriver/releases/download/$GECKO_VERSION/$FILENAME"
 
-    test -e /usr/local/bin/geckodriver &&  echo "geckodriver already installed" && exit 0
+    test -e /usr/local/bin/geckodriver && \
+        test "$GECKO_VERSION" = "v$(geckodriver --version | head -1 | awk '{ print $2 }')" && \
+        echo "geckodriver already installed" && \
+        exit 0
 
     mkdir -p $DL_DIR
     cd $DL_DIR
