@@ -1,22 +1,7 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 
 from contextlib import contextmanager
-from time import sleep
+import time
 
 from selenium.common.exceptions import StaleElementReferenceException
 from selenium.webdriver.support.ui import WebDriverWait
@@ -49,30 +34,45 @@ def is_not_running(browser, service_name):
 def eventually(function, args=[], timeout=30):
     """Execute a function returning a boolean expression till it returns
     True or a timeout is reached"""
-    counter = 1
-    while counter < timeout:
+    end_time = time.time() + timeout
+    current_time = time.time()
+    while current_time < end_time:
         if function(*args):
             return True
-        else:
-            counter += 1
-            sleep(1)
+
+        time.sleep(0.1)
+        current_time = time.time()
+
     return False
 
 
 @contextmanager
-def wait_for_page_update(browser, timeout=300):
-    current_page = browser.find_by_tag('body').first
+def wait_for_page_update(browser, timeout=300, expected_url=None):
+    page_body = browser.find_by_tag('body').first
     yield
-    WebDriverWait(browser, timeout).until(is_stale(current_page))
+    WebDriverWait(browser, timeout).until(page_loaded(page_body, expected_url))
 
 
-class is_stale():
-    def __init__(self, element):
+class page_loaded():
+    """
+    Wait until a page (re)loaded.
+
+    - element: Wait until this element gets stale
+    - expected_url (optional): Wait for the URL to become <expected_url>.
+      This can be necessary to wait for a redirect to finish.
+    """
+    def __init__(self, element, expected_url=None):
         self.element = element
+        self.expected_url = expected_url
 
     def __call__(self, driver):
+        is_stale = False
         try:
             self.element.has_class('whatever_class')
-            return False
         except StaleElementReferenceException:
-            return True
+            if self.expected_url is None:
+                is_stale = True
+            else:
+                if driver.url.endswith(self.expected_url):
+                    is_stale = True
+        return is_stale
