@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 
 import tempfile
 from urllib.parse import urlparse
@@ -95,7 +80,7 @@ def set_language(browser, language_code):
 
 def check_language(browser, language_code):
     nav_to_module(browser, 'config')
-    return browser.find_by_css('.header-bar').first.find_by_tag(
+    return browser.find_by_css('.app-titles').first.find_by_tag(
         'h2').first.value == config_page_title_language_map[language_code]
 
 
