@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 Forms for backups module.
 """
@@ -43,10 +28,10 @@ def _get_app_choices(apps):
     """Return a list of check box multiple choices from list of apps."""
     choices = []
     for app in apps:
-        name = app.app.name
+        name = app.app.app.info.name
         if not app.has_data:
             name = ugettext('{app} (No data to backup)').format(
-                app=app.app.name)
+                app=app.app.app.info.name)
 
         choices.append((app.name, name))
 
