@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for basic system configuration.
 """
@@ -34,16 +19,12 @@ version = 2
 
 is_essential = True
 
-name = _('General Configuration')
-
-description = [
+_description = [
     _('Here you can set some general configuration options '
       'like hostname, domain name, webserver home page etc.')
 ]
 
-depends = ['firewall', 'names']
-
-manual_page = 'Configure'
+depends = ['apache', 'firewall', 'names']
 
 APACHE_CONF_ENABLED_DIR = '/etc/apache2/conf-enabled'
 APACHE_HOMEPAGE_CONF_FILE_NAME = 'freedombox-apache-homepage.conf'
@@ -64,7 +45,14 @@ class ConfigApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-config', _('Configure'), None, 'fa-cog',
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               is_essential=is_essential, depends=depends,
+                               name=_('General Configuration'), icon='fa-cog',
+                               description=_description,
+                               manual_page='Configure')
+        self.add(info)
+
+        menu_item = menu.Menu('menu-config', _('Configure'), None, info.icon,
                               'config:index', parent_url_name='system')
         self.add(menu_item)
 
