@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox views for basic system configuration.
 """
@@ -35,11 +20,8 @@ LOGGER = logging.getLogger(__name__)
 
 class ConfigAppView(views.AppView):
     """Serve configuration page."""
-    name = config.name
-    description = config.description
     form_class = ConfigurationForm
     app_id = 'config'
-    manual_page = config.manual_page
     show_status_block = False
 
     def get_initial(self):
