@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 Plinth module to configure coquelicot.
 """
@@ -29,19 +14,13 @@ from plinth.modules.firewall.components import Firewall
 
 from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
-clients = clients
-
 version = 1
 
 managed_services = ['coquelicot']
 
 managed_packages = ['coquelicot']
 
-name = _('Coquelicot')
-
-short_description = _('File Sharing')
-
-description = [
+_description = [
     _('Coquelicot is a "one-click" file sharing web application with a focus '
       'on protecting users\' privacy. It is best used for quickly sharing a '
       'single file. '),
@@ -51,8 +30,6 @@ description = [
       'The default upload password is "test".')
 ]
 
-manual_page = 'Coquelicot'
-
 app = None
 
 
@@ -64,18 +41,27 @@ class CoquelicotApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-coquelicot', name, short_description,
-                              'coquelicot', 'coquelicot:index',
-                              parent_url_name='apps')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Coquelicot'),
+                               icon_filename='coquelicot',
+                               short_description=_('File Sharing'),
+                               description=_description,
+                               manual_page='Coquelicot', clients=clients)
+        self.add(info)
+
+        menu_item = menu.Menu('menu-coquelicot', info.name,
+                              info.short_description, info.icon_filename,
+                              'coquelicot:index', parent_url_name='apps')
         self.add(menu_item)
 
-        shortcut = frontpage.Shortcut('shortcut-coquelicot', name,
-                                      short_description=short_description,
+        shortcut = frontpage.Shortcut('shortcut-coquelicot', info.name,
+                                      short_description=info.short_description,
                                       icon='coquelicot', url='/coquelicot',
-                                      clients=clients, login_required=True)
+                                      clients=info.clients,
+                                      login_required=True)
         self.add(shortcut)
 
-        firewall = Firewall('firewall-coquelicot', name,
+        firewall = Firewall('firewall-coquelicot', info.name,
                             ports=['http', 'https'], is_external=True)
         self.add(firewall)
 
