@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 Plinth views for Coquelicot.
 """
@@ -23,22 +8,16 @@ from django.utils.translation import ugettext as _
 
 from plinth import actions, views
 from plinth.errors import ActionError
-from plinth.modules.coquelicot import (clients, description,
-                                       get_current_max_file_size, manual_page,
-                                       name)
+from plinth.modules.coquelicot import get_current_max_file_size
 
 from .forms import CoquelicotForm
 
 
 class CoquelicotAppView(views.AppView):
     """Serve configuration page."""
-    clients = clients
-    name = name
-    description = description
     app_id = 'coquelicot'
     form_class = CoquelicotForm
     show_status_block = True
-    manual_page = manual_page
 
     def get_initial(self):
         """Return the status of the service to fill in the form."""
