@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for configuring date and time.
 """
@@ -24,7 +9,6 @@ from django.contrib import messages
 from django.utils.translation import ugettext as _
 
 from plinth import actions
-from plinth.modules import datetime
 from plinth.views import AppView
 
 from .forms import DateTimeForm
@@ -33,11 +17,8 @@ logger = logging.getLogger(__name__)
 
 
 class DateTimeAppView(AppView):
-    name = datetime.name
-    description = datetime.description
     form_class = DateTimeForm
     app_id = 'datetime'
-    manual_page = datetime.manual_page
 
     def get_initial(self):
         status = super().get_initial()
