@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for system diagnostics.
 """
@@ -30,16 +15,12 @@ version = 1
 
 is_essential = True
 
-name = _('Diagnostics')
-
-description = [
+_description = [
     _('The system diagnostic test will run a number of checks on your '
       'system to confirm that applications and services are working as '
       'expected.')
 ]
 
-manual_page = 'Diagnostics'
-
 app = None
 
 
@@ -51,7 +32,14 @@ class DiagnosticsApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-diagnostics', name, None, 'fa-heartbeat',
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               is_essential=is_essential,
+                               name=_('Diagnostics'), icon='fa-heartbeat',
+                               description=_description,
+                               manual_page='Diagnostics')
+        self.add(info)
+
+        menu_item = menu.Menu('menu-diagnostics', info.name, None, info.icon,
                               'diagnostics:index', parent_url_name='system')
         self.add(menu_item)
 
