@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for running diagnostics.
 """
@@ -45,10 +30,8 @@ def index(request):
 
     return TemplateResponse(
         request, 'diagnostics.html', {
-            'name': diagnostics.name,
-            'description': diagnostics.description,
+            'app_info': diagnostics.app.info,
             'is_running': _running_task is not None,
-            'manual_page': diagnostics.manual_page,
             'results': current_results
         })
 
