@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure XMPP web client/jsxc.
 """
@@ -33,19 +18,11 @@ version = 1
 
 managed_packages = ['libjs-jsxc']
 
-name = _('JSXC')
-
-icon_filename = 'jsxc'
-
-short_description = _('Chat Client')
-
-description = [
+_description = [
     _('JSXC is a web client for XMPP. Typically it is used with an XMPP '
       'server running locally.'),
 ]
 
-clients = clients
-
 logger = logging.getLogger(__name__)
 
 app = None
@@ -59,19 +36,26 @@ class JSXCApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-jsxc', name, short_description, 'jsxc',
-                              'jsxc:index', parent_url_name='apps')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('JSXC'), icon_filename='jsxc',
+                               short_description=_('Chat Client'),
+                               description=_description, clients=clients)
+        self.add(info)
+
+        menu_item = menu.Menu('menu-jsxc', info.name, info.short_description,
+                              info.icon_filename, 'jsxc:index',
+                              parent_url_name='apps')
         self.add(menu_item)
 
-        shortcut = frontpage.Shortcut('shortcut-jsxc', name=name,
-                                      short_description=short_description,
-                                      icon=icon_filename,
+        shortcut = frontpage.Shortcut('shortcut-jsxc', name=info.name,
+                                      short_description=info.short_description,
+                                      icon=info.icon_filename,
                                       url=reverse_lazy('jsxc:jsxc'),
-                                      clients=clients)
+                                      clients=info.clients)
         self.add(shortcut)
 
-        firewall = Firewall('firewall-jsxc', name, ports=['http', 'https'],
-                            is_external=True)
+        firewall = Firewall('firewall-jsxc', info.name,
+                            ports=['http', 'https'], is_external=True)
         self.add(firewall)
 
 
