@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for using Let's Encrypt.
 """
@@ -45,11 +30,7 @@ depends = ['names']
 
 managed_packages = ['certbot']
 
-name = _('Let\'s Encrypt')
-
-short_description = _('Certificates')
-
-description = [
+_description = [
     format_lazy(
         _('A digital certificate allows users of a web service to verify the '
           'identity of the service and to securely communicate with it. '
@@ -64,8 +45,6 @@ description = [
       'Subscriber Agreement</a> before using this service.')
 ]
 
-manual_page = 'LetsEncrypt'
-
 LIVE_DIRECTORY = '/etc/letsencrypt/live/'
 CERTIFICATE_CHECK_DELAY = 120
 logger = logging.getLogger(__name__)
@@ -81,9 +60,17 @@ class LetsEncryptApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-letsencrypt', name, short_description,
-                              'fa-lock', 'letsencrypt:index',
-                              parent_url_name='system')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               is_essential=is_essential, depends=depends,
+                               name=_('Let\'s Encrypt'), icon='fa-lock',
+                               short_description=_('Certificates'),
+                               description=_description,
+                               manual_page='LetsEncrypt')
+        self.add(info)
+
+        menu_item = menu.Menu('menu-letsencrypt', info.name,
+                              info.short_description, info.icon,
+                              'letsencrypt:index', parent_url_name='system')
         self.add(menu_item)
 
     def diagnose(self):
