@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for Minetest server.
 """
@@ -47,13 +32,7 @@ mods = [
 
 managed_packages = ['minetest-server'] + mods
 
-name = _('Minetest')
-
-icon_filename = 'minetest'
-
-short_description = _('Block Sandbox')
-
-description = [
+_description = [
     format_lazy(
         _('Minetest is a multiplayer infinite-world block sandbox. This '
           'module enables the Minetest server to be run on this '
@@ -62,10 +41,6 @@ description = [
           'is needed.'), box_name=_(cfg.box_name)),
 ]
 
-clients = clients
-
-manual_page = 'Minetest'
-
 port_forwarding_info = [('UDP', 30000)]
 
 reserved_usernames = ['Debian-minetest']
@@ -84,19 +59,27 @@ class MinetestApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-minetest', name, short_description,
-                              'minetest', 'minetest:index',
-                              parent_url_name='apps')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Minetest'), icon_filename='minetest',
+                               short_description=_('Block Sandbox'),
+                               description=_description,
+                               manual_page='Minetest', clients=clients)
+        self.add(info)
+
+        menu_item = menu.Menu('menu-minetest', info.name,
+                              info.short_description, info.icon_filename,
+                              'minetest:index', parent_url_name='apps')
         self.add(menu_item)
 
         shortcut = frontpage.Shortcut(
-            'shortcut-minetest', name, short_description=short_description,
-            icon=icon_filename, description=description,
-            configure_url=reverse_lazy('minetest:index'), clients=clients,
+            'shortcut-minetest', info.name,
+            short_description=info.short_description, icon=info.icon_filename,
+            description=info.description,
+            configure_url=reverse_lazy('minetest:index'), clients=info.clients,
             login_required=False)
         self.add(shortcut)
 
-        firewall = Firewall('firewall-minetest', name,
+        firewall = Firewall('firewall-minetest', info.name,
                             ports=['minetest-plinth'], is_external=True)
         self.add(firewall)
 
