@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 Views for minetest module.
 """
@@ -25,22 +10,17 @@ from plinth import actions
 from plinth.modules import minetest, names
 from plinth.views import AppView
 
-from . import description, get_configuration
+from . import get_configuration
 from .forms import MinetestForm
 
 
 class MinetestAppView(AppView):  # pylint: disable=too-many-ancestors
     """A specialized view for configuring minetest."""
     app_id = 'minetest'
-    name = minetest.name
-    description = description
     show_status_block = True
     template_name = 'minetest.html'
     form_class = MinetestForm
-    clients = minetest.clients
-    manual_page = minetest.manual_page
     port_forwarding_info = minetest.port_forwarding_info
-    icon_filename = minetest.icon_filename
 
     def get_initial(self):
         """Return the values to fill in the form."""
