@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 Views for the monkeysphere module.
 """
@@ -39,11 +24,9 @@ def index(request):
     status = get_status()
     return TemplateResponse(
         request, 'monkeysphere.html', {
-            'title': monkeysphere.name,
-            'name': monkeysphere.name,
-            'description': monkeysphere.description,
+            'app_info': monkeysphere.app.info,
+            'title': monkeysphere.app.info.name,
             'status': status,
-            'manual_page': monkeysphere.manual_page,
             'running': bool(publish_process)
         })
 
@@ -67,7 +50,7 @@ def import_key(request, ssh_fingerprint):
 def details(request, fingerprint):
     """Get details for an OpenPGP key."""
     return TemplateResponse(request, 'monkeysphere_details.html', {
-        'title': monkeysphere.name,
+        'title': monkeysphere.app.info.name,
         'key': get_key(fingerprint)
     })
 
