@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure name services.
 """
@@ -34,13 +19,9 @@ version = 1
 
 is_essential = True
 
-name = _('Name Services')
-
 logger = logging.getLogger(__name__)
 
-manual_page = 'NameServices'
-
-description = [
+_description = [
     format_lazy(
         _('Name Services provides an overview of the ways {box_name} can be '
           'reached from the public Internet: domain name, Tor onion service, '
@@ -60,7 +41,14 @@ class NamesApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-names', name, None, 'fa-tags',
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               is_essential=is_essential,
+                               name=_('Name Services'), icon='fa-tags',
+                               description=_description,
+                               manual_page='NameServices')
+        self.add(info)
+
+        menu_item = menu.Menu('menu-names', info.name, None, info.icon,
                               'names:index', parent_url_name='system')
         self.add(menu_item)
 
