@@ -1,28 +1,12 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 
 from django import forms
 from django.core import validators
-from django.utils.translation import ugettext_lazy as _, ugettext_lazy
-from markupsafe import Markup
+from django.utils.translation import ugettext_lazy as _
 
-from plinth import cfg
-from plinth import network
+from plinth import cfg, network
 from plinth.utils import format_lazy, import_from_gi
+
 nm = import_from_gi('NM', '1.0')
 
 
@@ -54,12 +38,11 @@ class ConnectionForm(forms.Form):
         choices=[('external', _('External')), ('internal', _('Internal'))])
     ipv4_method = forms.ChoiceField(
         label=_('IPv4 Addressing Method'), help_text=format_lazy(
-            ugettext_lazy(
-                '"Automatic" method will make {box_name} acquire '
-                'configuration from this network making it a client. "Shared" '
-                'method will make {box_name} act as a router, configure '
-                'clients on this network and share its Internet connection.'),
-            box_name=ugettext_lazy(cfg.box_name)),
+            _('"Automatic" method will make {box_name} acquire '
+              'configuration from this network making it a client. "Shared" '
+              'method will make {box_name} act as a router, configure '
+              'clients on this network and share its Internet connection.'),
+            box_name=_(cfg.box_name)),
         choices=[('auto', _('Automatic (DHCP)')), ('shared', _('Shared')),
                  ('manual', _('Manual')), ('disabled', _('Disabled'))])
     ipv4_address = forms.CharField(
@@ -87,10 +70,9 @@ class ConnectionForm(forms.Form):
         validators=[validators.validate_ipv4_address], required=False)
     ipv6_method = forms.ChoiceField(
         label=_('IPv6 Addressing Method'), help_text=format_lazy(
-            ugettext_lazy(
-                '"Automatic" methods will make {box_name} acquire '
-                'configuration from this network making it a client.'),
-            box_name=ugettext_lazy(cfg.box_name)),
+            _('"Automatic" methods will make {box_name} acquire '
+              'configuration from this network making it a client.'),
+            box_name=_(cfg.box_name)),
         choices=[('auto', _('Automatic')), ('dhcp', _('Automatic, DHCP only')),
                  ('manual', _('Manual')), ('ignore', _('Ignore'))])
     ipv6_address = forms.CharField(
@@ -303,56 +285,106 @@ requires clients to have the password to connect.'),
         return settings
 
 
-class RouterConfigurationWizardForm(forms.Form):
+class InternetConnectionTypeForm(forms.Form):
+    """Form for type of public/private IP address ISP provides.
+
+    Ask the user for what type of Internet connection they have. We store this
+    information and use it suggest various setup options during the setup
+    process and also later on when setting up apps.
+
     """
-    Form to suggest router configuration depending on wan
-    connectivity/specific setup. The choice will affect
-    future suggestions during the setup process and other apps.
+    internet_connection_type = forms.ChoiceField(
+        label=_('Choose your internet connection type'),
+        choices=[
+            ('dynamic_public_ip',
+             format_lazy(
+                 _('I have a public IP address that may change over time'
+                   '<p class="help-block">This means that devices on the '
+                   'Internet can reach you when you are connected to the '
+                   'Internet. Every time you connect to the Internet with '
+                   'your Internet Service Provider (ISP), you may get a '
+                   'different IP address, especially after some offline time. '
+                   'Many ISPs offer this type of connectivity. If you have a '
+                   'public IP address but are unsure if it changes over time '
+                   'or not, it is safer to choose this option.</p>'),
+                 allow_markup=True)),
+            ('static_public_ip',
+             format_lazy(
+                 _('I have a public IP address that does not change overtime '
+                   '(recommended)'
+                   '<p class="help-block">This means that devices on the '
+                   'Internet can reach you when you are connected to the '
+                   'Internet. Every time you connect to the Internet with '
+                   'your Internet Service Provider (ISP), you always get the '
+                   'same IP address. This is the most trouble-free setup for '
+                   'many {box_name} services but very few ISPs offer this. '
+                   'You may be able to get this service from your ISP by '
+                   'making an additional payment.</p>'), box_name=cfg.box_name,
+                 allow_markup=True)),
+            ('private_ip',
+             format_lazy(
+                 _('I dont have a public IP address'
+                   '<p class="help-block">This means that devices on the '
+                   'Internet <b>can not</b> reach you when you are connected '
+                   'to the Internet. Every time you connect to the Internet '
+                   'with your Internet Service Provider (ISP), you get an IP '
+                   'address that is only relevant for local networks. '
+                   'Many ISPs offer this type of connectivity. This is the '
+                   'most troublesome situation for hosting services at home. '
+                   '{box_name} provides many workaround solutions but each '
+                   'solution has some limitations.</p>'),
+                 box_name=cfg.box_name, allow_markup=True)),
+        ],
+        required=True,
+        widget=forms.RadioSelect,
+    )
+
+
+class RouterConfigurationWizardForm(forms.Form):
+    """Form to suggest how to configure a router.
+
+    Suggest depending on wan connectivity/specific setup. The choice will
+    affect future suggestions during the setup process and other apps.
+
     """
     router_config = forms.ChoiceField(
         label=_('Preferred router configuration'),
         choices=[
             (
                 'dmz',
-                Markup(format_lazy(
-                    _('Use DMZ feature to forward all traffic'
+                format_lazy(
+                    _('Use DMZ feature to forward all traffic (recommended) '
                       '<p class="help-block">Most routers provide a '
                       'configuration setting called DMZ. This will allow the '
                       'router to forward all incoming traffic from the '
-                      'internet to a single IP address such as the '
-                      '{box_name}\'s address. First remember to configure a '
-                      'static local IP address for your {box_name} in your '
-                      'router\'s configuration.</p>'),
-                    box_name=cfg.box_name
-                )),
-            ),
-            (
-                'port_forwarding',
-                Markup(format_lazy(
-                    _('Forward Specific Traffic as needed by each '
-                      'application'
-                      '<p class="help-block">You may alternatively choose to '
-                      'forward only specific traffic to your {box_name}. '
-                      'This is ideal if you have other servers like '
-                      '{box_name} in your network or if your router does not '
-                      'support DMZ feature. All applications that provide a '
-                      'web interface need you to forward traffic from ports '
-                      '80 and 443 to work. Each of the other applications '
-                      'will suggest which port(s) need to be forwarded '
-                      'for that application to work.</p>'),
-                    box_name=cfg.box_name
-                ))
-            ),
-            (
-                'not_configured',
-                Markup(
-                    _('Router is currently unconfigured'
-                      '<p class="help-block">Choose this if you have not '
-                      'configured or are unable to configure the router '
-                      'currently and wish to be reminded later. Some of '
-                      'the other configuration steps may fail.</p>')
-                )
+                      'Internet to a single IP address such as the '
+                      '{box_name}\'s IP address. First remember to configure '
+                      'a static local IP address for your {box_name} in your '
+                      'router\'s configuration.</p>'), box_name=cfg.box_name,
+                    allow_markup=True),
             ),
+            ('port_forwarding',
+             format_lazy(
+                 _('Forward specific traffic as needed by each '
+                   'application '
+                   '<p class="help-block">You may alternatively choose to '
+                   'forward only specific traffic to your {box_name}. '
+                   'This is ideal if you have other servers like '
+                   '{box_name} in your network or if your router does not '
+                   'support DMZ feature. All applications that provide a '
+                   'web interface need you to forward traffic from ports '
+                   '80 and 443 to work. Each of the other applications '
+                   'will suggest which port(s) need to be forwarded '
+                   'for that application to work.</p>'), box_name=cfg.box_name,
+                 allow_markup=True)),
+            ('not_configured',
+             format_lazy(
+                 _('Router is currently unconfigured '
+                   '<p class="help-block">Choose this if you have not '
+                   'configured or are unable to configure the router '
+                   'currently and wish to be reminded later. Some of '
+                   'the other configuration steps may fail.</p>'),
+                 allow_markup=True)),
         ],
         required=True,
         widget=forms.RadioSelect,
