@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure PageKite.
 """
@@ -36,11 +21,7 @@ managed_services = ['pagekite']
 
 managed_packages = ['pagekite']
 
-name = _('PageKite')
-
-short_description = _('Public Visibility')
-
-description = [
+_description = [
     format_lazy(
         _('PageKite is a system for exposing {box_name} services when '
           'you don\'t have a direct connection to the Internet. You only '
@@ -66,8 +47,6 @@ description = [
         box_name=_(cfg.box_name))
 ]
 
-manual_page = 'PageKite'
-
 app = None
 
 
@@ -79,9 +58,17 @@ class PagekiteApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-pagekite', name, short_description,
-                              'fa-flag', 'pagekite:index',
-                              parent_url_name='system')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               depends=depends, name=_('PageKite'),
+                               icon='fa-flag',
+                               short_description=_('Public Visibility'),
+                               description=_description,
+                               manual_page='PageKite')
+        self.add(info)
+
+        menu_item = menu.Menu('menu-pagekite', info.name,
+                              info.short_description, info.icon,
+                              'pagekite:index', parent_url_name='system')
         self.add(menu_item)
 
         domain_type = DomainType('domain-type-pagekite', _('PageKite Domain'),
