@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for power module.
 """
@@ -22,7 +7,6 @@ from django.forms import Form
 from django.shortcuts import redirect
 from django.template.response import TemplateResponse
 from django.urls import reverse
-from django.utils.translation import ugettext as _
 
 from plinth import actions
 from plinth.modules import power
@@ -32,10 +16,8 @@ def index(request):
     """Serve power controls page."""
     return TemplateResponse(
         request, 'power.html', {
-            'title': power.name,
-            'name': power.name,
-            'description': power.description,
-            'manual_page': power.manual_page,
+            'title': power.app.info.name,
+            'app_info': power.app.info,
             'pkg_manager_is_busy': _is_pkg_manager_busy()
         })
 
@@ -52,9 +34,9 @@ def restart(request):
 
     return TemplateResponse(
         request, 'power_restart.html', {
-            'title': _('Power'),
+            'title': power.app.info.name,
             'form': form,
-            'manual_page': power.manual_page,
+            'manual_page': power.app.info.manual_page,
             'pkg_manager_is_busy': _is_pkg_manager_busy()
         })
 
@@ -71,9 +53,9 @@ def shutdown(request):
 
     return TemplateResponse(
         request, 'power_shutdown.html', {
-            'title': _('Power'),
+            'title': power.app.info.name,
             'form': form,
-            'manual_page': power.manual_page,
+            'manual_page': power.app.info.manual_page,
             'pkg_manager_is_busy': _is_pkg_manager_busy()
         })
 
