@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure Privoxy.
 """
@@ -40,13 +25,7 @@ managed_services = ['privoxy']
 
 managed_packages = ['privoxy']
 
-name = _('Privoxy')
-
-icon_filename = 'privoxy'
-
-short_description = _('Web Proxy')
-
-description = [
+_description = [
     _('Privoxy is a non-caching web proxy with advanced filtering '
       'capabilities for enhancing privacy, modifying web page data and '
       'HTTP headers, controlling access, and removing ads and other '
@@ -63,8 +42,6 @@ description = [
 
 reserved_usernames = ['privoxy']
 
-manual_page = 'Privoxy'
-
 app = None
 
 
@@ -76,18 +53,25 @@ class PrivoxyApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-privoxy', name, short_description,
-                              'privoxy', 'privoxy:index',
-                              parent_url_name='apps')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Privoxy'), icon_filename='privoxy',
+                               short_description=_('Web Proxy'),
+                               description=_description, manual_page='Privoxy')
+        self.add(info)
+
+        menu_item = menu.Menu('menu-privoxy', info.name,
+                              info.short_description, info.icon_filename,
+                              'privoxy:index', parent_url_name='apps')
         self.add(menu_item)
 
         shortcut = frontpage.Shortcut(
-            'shortcut-privoxy', name, short_description=short_description,
-            icon=icon_filename, description=description,
+            'shortcut-privoxy', info.name,
+            short_description=info.short_description, icon=info.icon_filename,
+            description=info.description,
             configure_url=reverse_lazy('privoxy:index'), login_required=True)
         self.add(shortcut)
 
-        firewall = Firewall('firewall-privoxy', name, ports=['privoxy'],
+        firewall = Firewall('firewall-privoxy', info.name, ports=['privoxy'],
                             is_external=False)
         self.add(firewall)
 
@@ -122,10 +106,6 @@ def setup(helper, old_version=None):
 
 class PrivoxyAppView(AppView):
     app_id = 'privoxy'
-    name = name
-    description = description
-    manual_page = manual_page
-    icon_filename = icon_filename
 
 
 def diagnose_url_with_proxy():
