@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure Roundcube.
 """
@@ -32,13 +17,7 @@ version = 1
 
 managed_packages = ['sqlite3', 'roundcube', 'roundcube-sqlite3']
 
-name = _('Roundcube')
-
-icon_filename = 'roundcube'
-
-short_description = _('Email Client')
-
-description = [
+_description = [
     _('Roundcube webmail is a browser-based multilingual IMAP '
       'client with an application-like user interface. It provides '
       'full functionality you expect from an email client, including '
@@ -58,8 +37,6 @@ description = [
       '>https://www.google.com/settings/security/lesssecureapps</a>).'),
 ]
 
-clients = clients
-
 manual_page = 'Roundcube'
 
 app = None
@@ -73,18 +50,26 @@ class RoundcubeApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-roundcube', name, short_description,
-                              'roundcube', 'roundcube:index',
-                              parent_url_name='apps')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Roundcube'), icon_filename='roundcube',
+                               short_description=_('Email Client'),
+                               description=_description,
+                               manual_page='Roundcube', clients=clients)
+        self.add(info)
+
+        menu_item = menu.Menu('menu-roundcube', info.name,
+                              info.short_description, info.icon_filename,
+                              'roundcube:index', parent_url_name='apps')
         self.add(menu_item)
 
-        shortcut = frontpage.Shortcut('shortcut-roundcube', name,
-                                      short_description=short_description,
-                                      icon=icon_filename, url='/roundcube/',
-                                      clients=clients, login_required=True)
+        shortcut = frontpage.Shortcut('shortcut-roundcube', info.name,
+                                      short_description=info.short_description,
+                                      icon=info.icon_filename,
+                                      url='/roundcube/', clients=info.clients,
+                                      login_required=True)
         self.add(shortcut)
 
-        firewall = Firewall('firewall-roundcube', name,
+        firewall = Firewall('firewall-roundcube', info.name,
                             ports=['http', 'https'], is_external=True)
         self.add(firewall)
 
