@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure Shaarli.
 """
@@ -31,11 +16,7 @@ version = 1
 
 managed_packages = ['shaarli']
 
-name = _('Shaarli')
-
-short_description = _('Bookmarks')
-
-description = [
+_description = [
     _('Shaarli allows you to save and share bookmarks.'),
     _('When enabled, Shaarli will be available from <a href="/shaarli" '
       'data-turbolinks="false">/shaarli</a> path on the web server. Note that '
@@ -43,10 +24,6 @@ description = [
       'setup on the initial visit.'),
 ]
 
-clients = clients
-
-manual_page = 'Shaarli'
-
 app = None
 
 
@@ -58,19 +35,27 @@ class ShaarliApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-shaarli', name, short_description,
-                              'shaarli', 'shaarli:index',
-                              parent_url_name='apps')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Shaarli'), icon_filename='shaarli',
+                               short_description=_('Bookmarks'),
+                               description=_description, manual_page='Shaarli',
+                               clients=clients)
+        self.add(info)
+
+        menu_item = menu.Menu('menu-shaarli', info.name,
+                              info.short_description, info.icon_filename,
+                              'shaarli:index', parent_url_name='apps')
         self.add(menu_item)
 
-        shortcut = frontpage.Shortcut('shortcut-shaarli', name,
-                                      short_description=short_description,
-                                      icon='shaarli', url='/shaarli',
-                                      clients=clients, login_required=True)
+        shortcut = frontpage.Shortcut('shortcut-shaarli', info.name,
+                                      short_description=info.short_description,
+                                      icon=info.icon_filename, url='/shaarli',
+                                      clients=info.clients,
+                                      login_required=True)
         self.add(shortcut)
 
-        firewall = Firewall('firewall-shaarli', name, ports=['http', 'https'],
-                            is_external=True)
+        firewall = Firewall('firewall-shaarli', info.name,
+                            ports=['http', 'https'], is_external=True)
         self.add(firewall)
 
         webserver = Webserver('webserver-shaarli', 'shaarli')
