@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure Shadowsocks.
 """
@@ -32,17 +17,11 @@ from .manifest import backup  # noqa, pylint: disable=unused-import
 
 version = 1
 
-name = _('Shadowsocks')
-
-icon_filename = 'shadowsocks'
-
-short_description = _('Socks5 Proxy')
-
 managed_services = ['shadowsocks-libev-local@freedombox']
 
 managed_packages = ['shadowsocks-libev']
 
-description = [
+_description = [
     _('Shadowsocks is a lightweight and secure SOCKS5 proxy, designed to '
       'protect your Internet traffic. It can be used to bypass Internet '
       'filtering and censorship.'),
@@ -56,8 +35,6 @@ description = [
       'device, browser or application to http://freedombox_address:1080/')
 ]
 
-manual_page = 'Shadowsocks'
-
 app = None
 
 
@@ -69,19 +46,28 @@ class ShadowsocksApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-shadowsocks', name, short_description,
-                              'shadowsocks', 'shadowsocks:index',
-                              parent_url_name='apps')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Shadowsocks'),
+                               icon_filename='shadowsocks',
+                               short_description=_('Socks5 Proxy'),
+                               description=_description,
+                               manual_page='Shadowsocks')
+        self.add(info)
+
+        menu_item = menu.Menu('menu-shadowsocks', info.name,
+                              info.short_description, info.icon_filename,
+                              'shadowsocks:index', parent_url_name='apps')
         self.add(menu_item)
 
         shortcut = frontpage.Shortcut(
-            'shortcut-shadowsocks', name, short_description=short_description,
-            icon=icon_filename, description=description,
+            'shortcut-shadowsocks', info.name,
+            short_description=info.short_description, icon=info.icon_filename,
+            description=info.description,
             configure_url=reverse_lazy('shadowsocks:index'),
             login_required=True)
         self.add(shortcut)
 
-        firewall = Firewall('firewall-shadowsocks', name,
+        firewall = Firewall('firewall-shadowsocks', info.name,
                             ports=['shadowsocks-local-plinth'],
                             is_external=False)
         self.add(firewall)
