@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for configuring Shadowsocks.
 """
@@ -25,7 +10,6 @@ from django.utils.translation import ugettext_lazy as _
 
 from plinth import actions, views
 from plinth.errors import ActionError
-from plinth.modules import shadowsocks
 
 from .forms import ShadowsocksForm
 
@@ -34,10 +18,6 @@ class ShadowsocksAppView(views.AppView):
     """Configuration view for Shadowsocks local socks5 proxy."""
     app_id = 'shadowsocks'
     form_class = ShadowsocksForm
-    name = shadowsocks.name
-    description = shadowsocks.description
-    manual_page = shadowsocks.manual_page
-    icon_filename = shadowsocks.icon_filename
 
     def get_initial(self, *args, **kwargs):
         """Get initial values for form."""
