@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure sharing.
 """
@@ -31,9 +16,7 @@ from .manifest import backup  # noqa, pylint: disable=unused-import
 
 version = 1
 
-name = _('Sharing')
-
-description = [
+_description = [
     format_lazy(
         _('Sharing allows you to share files and folders on your {box_name} '
           'over the web with chosen groups of users.'),
@@ -42,8 +25,6 @@ description = [
 
 app = None
 
-icon_filename = 'sharing'
-
 
 class SharingApp(app_module.App):
     """FreedomBox app for sharing files."""
@@ -53,8 +34,14 @@ class SharingApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-sharing', name, None, 'sharing',
-                              'sharing:index', parent_url_name='apps')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Sharing'), icon_filename='sharing',
+                               description=_description)
+        self.add(info)
+
+        menu_item = menu.Menu('menu-sharing', info.name, None,
+                              info.icon_filename, 'sharing:index',
+                              parent_url_name='apps')
         self.add(menu_item)
 
 
