@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to manage filesystem snapshots.
 """
@@ -34,9 +19,7 @@ version = 4
 
 managed_packages = ['snapper']
 
-name = _('Storage Snapshots')
-
-description = [
+_description = [
     _('Snapshots allows creating and managing btrfs file system snapshots. '
       'These can be used to roll back the system to a previously known '
       'good state in case of unwanted changes to the system.'),
@@ -50,8 +33,6 @@ description = [
       'they can only be stored on the same partition. ')
 ]
 
-manual_page = 'Snapshots'
-
 DEFAULT_FILE = '/etc/default/snapper'
 
 fs_types_supported = ['btrfs']
@@ -67,7 +48,13 @@ class SnapshotApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-snapshot', name, None, 'fa-film',
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Storage Snapshots'), icon='fa-film',
+                               description=_description,
+                               manual_page='Snapshots')
+        self.add(info)
+
+        menu_item = menu.Menu('menu-snapshot', info.name, None, info.icon,
                               'snapshot:index', parent_url_name='system')
         self.add(menu_item)
 
