@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for OpenSSH server.
 """
@@ -40,9 +25,7 @@ managed_services = ['ssh']
 
 managed_packages = ['openssh-server']
 
-name = _('Secure Shell (SSH) Server')
-
-description = [
+_description = [
     _('A Secure Shell server uses the secure shell protocol to accept '
       'connections from remote computers. An authorized remote computer '
       'can perform administration tasks, copy files or run other services '
@@ -62,11 +45,17 @@ class SSHApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-ssh', name, None, 'fa-terminal',
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               is_essential=is_essential,
+                               name=_('Secure Shell (SSH) Server'),
+                               icon='fa-terminal', description=_description)
+        self.add(info)
+
+        menu_item = menu.Menu('menu-ssh', info.name, None, info.icon,
                               'ssh:index', parent_url_name='system')
         self.add(menu_item)
 
-        firewall = Firewall('firewall-ssh', name, ports=['ssh'],
+        firewall = Firewall('firewall-ssh', info.name, ports=['ssh'],
                             is_external=True)
         self.add(firewall)
 
