@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure Tahoe-LAFS.
 """
@@ -21,6 +6,7 @@ FreedomBox app to configure Tahoe-LAFS.
 import json
 import os
 
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from plinth import actions
@@ -40,11 +26,16 @@ managed_services = ['tahoe-lafs']
 
 managed_packages = ['tahoe-lafs']
 
-name = _('Tahoe-LAFS')
-
-icon_filename = 'tahoe-lafs'
-
-short_description = _('Distributed File Storage')
+_description = [
+    _('Tahoe-LAFS is a decentralized secure file storage system. '
+      'It uses provider independent security to store files over a '
+      'distributed network of storage nodes. Even if some of the nodes fail, '
+      'your files can be retrieved from the remaining nodes.'),
+    format_lazy(
+        _('This {box_name} hosts a storage node and an introducer by default. '
+          'Additional introducers can be added, which will introduce this '
+          'node to the other storage nodes.'), box_name=_(cfg.box_name)),
+]
 
 port_forwarding_info = [
     ('TCP', 3456),
@@ -71,19 +62,28 @@ class TahoeApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-tahoe', name, short_description,
-                              'tahoe-lafs', 'tahoe:index',
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Tahoe-LAFS'),
+                               icon_filename='tahoe-lafs',
+                               short_description=_('Distributed File Storage'),
+                               description=_description)
+
+        self.add(info)
+
+        menu_item = menu.Menu('menu-tahoe', info.name, info.short_description,
+                              info.icon_filename, 'tahoe:index',
                               parent_url_name='apps', advanced=True)
         self.add(menu_item)
 
-        shortcut = frontpage.Shortcut('shortcut-tahoe', name,
-                                      short_description=short_description,
-                                      icon=icon_filename, url=None,
-                                      login_required=True)
+        shortcut = frontpage.Shortcut(
+            'shortcut-tahoe', info.name,
+            short_description=info.short_description, icon=info.icon_filename,
+            description=info.description, url=None,
+            configure_url=reverse_lazy('tahoe:index'), login_required=True)
         self.add(shortcut)
 
-        firewall = Firewall('firewall-tahoe', name, ports=['tahoe-plinth'],
-                            is_external=True)
+        firewall = Firewall('firewall-tahoe', info.name,
+                            ports=['tahoe-plinth'], is_external=True)
         self.add(firewall)
 
         webserver = Webserver('webserver-tahoe', 'tahoe-plinth')
@@ -130,18 +130,6 @@ def get_configured_domain_name():
             return dnf.read().rstrip()
 
 
-description = [
-    _('Tahoe-LAFS is a decentralized secure file storage system. '
-      'It uses provider independent security to store files over a '
-      'distributed network of storage nodes. Even if some of the nodes fail, '
-      'your files can be retrieved from the remaining nodes.'),
-    format_lazy(
-        _('This {box_name} hosts a storage node and an introducer by default. '
-          'Additional introducers can be added, which will introduce this '
-          'node to the other storage nodes.'), box_name=_(cfg.box_name)),
-]
-
-
 def init():
     """Initialize the module."""
     global app
