@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app to configure Tor.
 """
@@ -44,11 +29,7 @@ managed_packages = [
 
 managed_services = ['tor@plinth']
 
-name = _('Tor')
-
-short_description = _('Anonymity Network')
-
-description = [
+_description = [
     _('Tor is an anonymous communication system. You can learn more '
       'about it from the <a href="https://www.torproject.org/">Tor '
       'Project</a> website. For best protection when web surfing, the '
@@ -57,16 +38,10 @@ description = [
       'Tor Browser</a>.')
 ]
 
-clients = clients
-
 reserved_usernames = ['debian-tor']
 
-manual_page = 'Tor'
-
 app = None
 
-icon_filename = 'tor'
-
 
 class TorApp(app_module.App):
     """FreedomBox app for Tor."""
@@ -76,8 +51,16 @@ class TorApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-tor', name, short_description, 'tor',
-                              'tor:index', parent_url_name='apps')
+        info = app_module.Info(app_id=self.app_id, version=version,
+                               name=_('Tor'), icon_filename='tor',
+                               short_description=_('Anonymity Network'),
+                               description=_description, manual_page='Tor',
+                               clients=clients)
+        self.add(info)
+
+        menu_item = menu.Menu('menu-tor', info.name, info.short_description,
+                              info.icon_filename, 'tor:index',
+                              parent_url_name='apps')
         self.add(menu_item)
 
         domain_type = DomainType('domain-type-tor', _('Tor Onion Service'),
