@@ -1,23 +1,9 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 
 from django.utils.translation import ugettext_lazy as _
 
 from plinth.clients import store_url, validate
+from plinth.modules.backups.api import validate as validate_backup
 
 _orbot_package_id = 'org.torproject.android'
 _tor_browser_download_url = \
@@ -54,3 +40,13 @@ clients = validate([{
         'url': store_url('f-droid', _orbot_package_id)
     }]
 }])
+
+backup = validate_backup({
+    'config': {
+        'directories': ['/etc/tor/']
+    },
+    'secrets': {
+        'directories': ['/var/lib/tor/', '/var/lib/tor-instances/']
+    },
+    'services': ['tor@service']
+})
