@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 FreedomBox app for configuring Tor.
 """
@@ -53,10 +38,7 @@ def index(request):
     return TemplateResponse(
         request, 'tor.html', {
             'app_id': 'tor',
-            'name': tor.name,
-            'description': tor.description,
-            'clients': tor.clients,
-            'manual_page': tor.manual_page,
+            'app_info': tor.app.info,
             'status': status,
             'config_running': bool(config_process),
             'form': form,
@@ -65,7 +47,6 @@ def index(request):
             'is_enabled': status['enabled'],
             'show_status_block': True,
             'is_running': status['is_running'],
-            'icon_filename': tor.icon_filename,
         })
 
 
