@@ -1,19 +1,4 @@
-#
-# This file is part of FreedomBox.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 
 import django.views.generic
 from django.contrib import messages
@@ -29,7 +14,7 @@ from django.views.generic.edit import (CreateView, DeleteView, FormView,
 
 from plinth import actions
 from plinth.errors import ActionError
-from plinth.modules import first_boot, users
+from plinth.modules import first_boot
 from plinth.utils import is_user_admin
 from plinth.views import AppView
 
@@ -72,11 +57,8 @@ class UserList(AppView, ContextMixin, django.views.generic.ListView):
     model = User
     template_name = 'users_list.html'
     title = ugettext_lazy('Users')
-    name = users.name
-    description = users.description
     app_id = 'users'
     show_status_block = False
-    manual_page = users.manual_page
 
     def get_context_data(self, *args, **kwargs):
         context = super(UserList, self).get_context_data(*args, **kwargs)
